@@ -1,4 +1,5 @@
 con = rmap_connect(); on.exit(dbDisconnect(con))
+wrens = read_wrens()
 rmap_add_ranges(con, x = wrens, ID = 'sci_name')
 rmap_prepare(con, 'hex', cellsize=1000)
 rmap_save_map(con) 
@@ -31,6 +32,7 @@ context(" -> Get: all maps <- ")
     test_that("rmap_to_sf gets all maps when src is missing", {
       m = rmap_to_sf(con)  
       expect_is(m , 'sf')
+      skip_on_os('solaris')
       expect_equal(ncol(m), 4)
      
       }) 
